Audio

Struct Audio 

pub struct Audio {
Show 26 fields pub mimes: Vec<String>, pub minduration: Option<i64>, pub maxduration: Option<i64>, pub poddur: Option<i64>, pub protocols: Option<Vec<i64>>, pub startdelay: Option<i64>, pub rqddurs: Option<Vec<i64>>, pub podid: Option<String>, pub podseq: Option<i64>, pub sequence: Option<i64>, pub slotinpod: Option<i64>, pub mincpmpersec: Option<f64>, pub battr: Option<Vec<i64>>, pub maxextended: Option<i64>, pub minbitrate: Option<i64>, pub maxbitrate: Option<i64>, pub delivery: Option<Vec<i64>>, pub companionad: Option<Vec<Banner>>, pub api: Option<Vec<i64>>, pub companiontype: Option<Vec<i64>>, pub maxseq: Option<i64>, pub feed: Option<i64>, pub stitched: Option<i64>, pub nvol: Option<i64>, pub durfloors: Option<Vec<DurFloors>>, pub ext: Option<Value>,
}
Represents an audio type impression.

Fields

mimes: Vec<String>

Content MIME types supported.

minduration: Option<i64>

Minimum audio ad duration in seconds. Recommended. Mutually exclusive with rqddurs.

maxduration: Option<i64>

Maximum audio ad duration in seconds. Recommended. Mutually exclusive with rqddurs.

poddur: Option<i64>

Total time in seconds for a dynamic audio ad pod. Required for dynamic portions. Recommended.

protocols: Option<Vec<i64>>

Array of supported audio protocols. Refer to AdCOM 1.0 List: Creative Subtypes - Audio/Video. Recommended.

startdelay: Option<i64>

Start delay in seconds for placements. Refer to AdCOM 1.0 List: Start Delay Modes. Recommended.

rqddurs: Option<Vec<i64>>

Precise acceptable durations for audio creatives in seconds. Mutually exclusive with minduration/maxduration.

podid: Option<String>

Unique identifier for audio ad pod impression belongs to.

podseq: Option<i64>

Sequence (position) of audio ad pod within content stream. Refer to AdCOM 1.0 List: Pod Sequence.

sequence: Option<i64>
👎Deprecated since 2.6.0:

Use slotinpod

DEPRECATED as of OpenRTB 2.6. Use slotinpod.

slotinpod: Option<i64>

Seller guarantees delivery against indicated slot position in pod. Refer to AdCOM 1.0 List: Slot Position in Pod.

mincpmpersec: Option<f64>

Minimum CPM per second for dynamic portion of audio ad pod.

battr: Option<Vec<i64>>

Blocked creative attributes. Refer to AdCOM 1.0 List: Creative Attributes.

maxextended: Option<i64>

Maximum extended ad duration if allowed. If blank/0, not allowed. -1=no limit. >0=seconds of extension.

minbitrate: Option<i64>

Minimum bit rate in Kbps.

maxbitrate: Option<i64>

Maximum bit rate in Kbps.

delivery: Option<Vec<i64>>

Supported delivery methods. Refer to AdCOM 1.0 List: Delivery Methods.

companionad: Option<Vec<Banner>>

Array of Banner objects if companion ads available.

api: Option<Vec<i64>>

List of supported API frameworks. Refer to AdCOM 1.0 List: API Frameworks.

companiontype: Option<Vec<i64>>

Supported companion ad types. Refer to AdCOM 1.0 List: Companion Types. Recommended if companionad included.

maxseq: Option<i64>

Maximum number of ads that can be played in an ad pod.

feed: Option<i64>

Type of audio feed. Refer to AdCOM 1.0 List: Feed Types.

stitched: Option<i64>

Indicates if ad is stitched (0=no, 1=yes).

nvol: Option<i64>

Volume normalization mode. Refer to AdCOM 1.0 List: Volume Normalization Modes.

durfloors: Option<Vec<DurFloors>>

Array of DurFloors objects indicating floor prices for various audio durations.

ext: Option<Value>

Placeholder for exchange-specific extensions.