pub struct Segment {
pub id: Option<String>,
pub name: Option<String>,
pub value: Option<String>,
pub ext: Option<Value>,
}Expand description
Key-value pairs conveying specific units of data within a Data object.
Fields
id: Option<String>ID of the data segment specific to the data provider.
name: Option<String>Name of the data segment specific to the data provider.
value: Option<String>String representation of the data segment value.
ext: Option<Value>Placeholder for exchange-specific extensions.