pub struct SupplyChain {
pub complete: i64,
pub nodes: Vec<SupplyChainNode>,
pub ver: String,
pub ext: Option<Value>,
}Expand description
Represents the chain of entities involved in the direct flow of payment for inventory.
Fields
complete: i64Flag indicating if chain contains all nodes back to owner (0=no, 1=yes).
nodes: Vec<SupplyChainNode>Array of SupplyChainNode objects in order.
ver: StringVersion of the supply chain specification.
ext: Option<Value>Placeholder for exchange-specific extensions.